@@ -14,8 +14,8 @@ Provides:
 * Scripted statistical workflows with prebuilt plots
 for common algorithms.
 """
-__version__ = "0.1.0"
-__author__ = "Joscha Christmann"
+__version__ = "0.1.2"
+__author__ = "Competency Center for Chemometrics Mannheim"
 __credits__ = "Competency Center for Chemometrics Mannheim"
 
 from ims.gcims import Spectrum
