@@ -12,7 +12,6 @@ from datetime import datetime
 from time import ctime
 from skimage.morphology import white_tophat, disk
 from zipfile import ZipFile
-import imageio
 
 
 class Spectrum:
@@ -56,7 +55,7 @@ class Spectrum:
         self.ret_time = ret_time
         self.drift_time = drift_time
         self.time = time
-        self._drift_time_label = 'Drift Time [ms]'
+        self._drift_time_label = 'Drift time [ms]'
         
     def __repr__(self):
         return f"GC-IMS Spectrum: {self.name}"
@@ -385,7 +384,7 @@ class Spectrum:
         rip_ms = self.drift_time[rip_index]
         dt_riprel = self.drift_time / rip_ms
         self.drift_time = dt_riprel
-        self._drift_time_label = 'Drift Time RIP relative'
+        self._drift_time_label = 'Drift time RIP relative'
         return self
 
     def rip_scaling(self):
@@ -627,7 +626,7 @@ class Spectrum:
         ax.yaxis.set_minor_locator(AutoMinorLocator())
 
         plt.xlabel(self._drift_time_label)
-        plt.ylabel("Retention Time [s]")
+        plt.ylabel("Retention time [s]")
 
         return fig, ax
 
@@ -660,30 +659,3 @@ class Spectrum:
         fig, _ = self.plot(**kwargs)
         fig.savefig(f'{path}/{self.name}.{file_format}', dpi=dpi,
                     bbox_inches="tight", pad_inches=0.2)
-
-    def export_image(self, path=None, file_format='jpeg'):
-        """
-        Exports spectrum as grayscale image (Not a plot!).
-
-        Parameters
-        ----------
-        path : str, optional
-            Directory to save the image,
-            by default current working directory.
-
-        file_format : str, optional
-            See imageio docs for supported formats:
-            https://imageio.readthedocs.io/en/stable/formats.html,
-            by default 'jpg'.
-
-        Example
-        -------
-        >>> import ims
-        >>> sample = ims.Spectrum.read_mea("sample.mea")
-        >>> sample.export_image()
-        """
-        if path is None:
-            path = os.getcwd()
-
-        imageio.imwrite(uri=f'{path}/{self.name}.{file_format}',
-                        im=self.values)
