@@ -165,6 +165,24 @@ class PLSR:
         """
         y_pred = self.predict(X_test)
         return r2_score(y_test, y_pred, sample_weight=sample_weight)
+    
+    
+    def transform(self, X, y=None):
+        """
+        Apply the dimensionality reduction.
+
+        Parameters
+        ----------
+        X : numpy.ndarray of shape (n_samples, n_features)
+            Feature matrix.
+        y : numpy.ndarray of shape (n_samples, n_targtets), optional
+            Dependend variables, by default None
+
+        Returns
+        -------
+        X_scores
+        """
+        return self._sk_pls.transform(X, y)
 
 
     def plot(self, width=9, height=8, annotate=False, test_only=True):
@@ -273,10 +291,10 @@ class PLSR:
                     min(ret_time), max(ret_time))
             )
 
-        plt.colorbar(label="PLS Loadings")
+        plt.colorbar(label="PLS loadings")
         plt.title(f"PLS loadings of component {component}")
         plt.xlabel(self.dataset[0]._drift_time_label)
-        plt.ylabel("Retention Time [s]")
+        plt.ylabel("Retention time [s]")
         ax.xaxis.set_minor_locator(AutoMinorLocator())
         ax.yaxis.set_minor_locator(AutoMinorLocator())
         return ax
@@ -316,10 +334,10 @@ class PLSR:
                     min(ret_time), max(ret_time))
             )
 
-        plt.colorbar(label="PLS Coefficients")
-        plt.title("PLS Coefficients")
+        plt.colorbar(label="PLS coefficients")
+        plt.title("PLS coefficients")
         plt.xlabel(self.dataset[0]._drift_time_label)
-        plt.ylabel("Retention Time [s]")
+        plt.ylabel("Retention time [s]")
         ax.xaxis.set_minor_locator(AutoMinorLocator())
         ax.yaxis.set_minor_locator(AutoMinorLocator())
         return ax
@@ -375,7 +393,7 @@ class PLSR:
         plt.colorbar(label="VIP scores")
         plt.title(f"PLS VIP scores")
         plt.xlabel(self.dataset[0]._drift_time_label)
-        plt.ylabel("Retention Time [s]")
+        plt.ylabel("Retention time [s]")
         ax.xaxis.set_minor_locator(AutoMinorLocator())
         ax.yaxis.set_minor_locator(AutoMinorLocator())
         return ax
@@ -423,10 +441,10 @@ class PLSR:
                     min(ret_time), max(ret_time))
             )
 
-        plt.colorbar(label="Selectivity Ratio")
-        plt.title(f"PLS Selectivity Ratio")
+        plt.colorbar(label="Selectivity ratio")
+        plt.title(f"PLS selectivity ratio")
         plt.xlabel(self.dataset[0]._drift_time_label)
-        plt.ylabel("Retention Time [s]")
+        plt.ylabel("Retention time [s]")
         ax.xaxis.set_minor_locator(AutoMinorLocator())
         ax.yaxis.set_minor_locator(AutoMinorLocator())
         return ax
